/*
;Software License Agreement                                         
;                                                                    
;The software supplied herewith by Microchip Technology             
;Incorporated (the "Company") is intended and supplied to you, the  
;Companys customer, for use solely and exclusively on Microchip    
;products. The software is owned by the Company and/or its supplier,
;and is protected under applicable copyright laws. All rights are   
;reserved. Any use in violation of the foregoing restrictions may   
;subject the user to criminal sanctions under applicable laws, as   
;well as to civil liability for the breach of the terms and         
;conditions of this license.                                        
;                                                                    
;THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,  
;WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED  
;TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A       
;PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,  
;IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR         
;CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.       
;****************************************************************************
;File Name:		SwchFltr.c
;Author:			w.r.brown
;Date:  			10 January 2003
;Version:		1.01
;Description:  Time averaging filter of switch contact
;
;Modified:		1.01 1/27/03 w.r.brown 
;					Changed processor to PIC12F675. Added initialization 
;					code to change analog inputs to digital I/O.
;****************************************************************************
;Notes
;****************************************************************************
;
;    LED D0 indicates an open switch. LED D1 indicates a closed switch.
;
;    This demonstrates a simple filtered switch debounce routine.
;    The switch position is monitored continuously. If the switch is closed the 
;    filter count is incremented, and if the the switch is open the filter
;    count is decremented. When, but not until, the filter count overflows the
;    switch is determined to be closed. Likewise, when the filter count 
;    underflows the switch is determined to be open. Filter hysterisis is
;    inherent in the number of counts between the filter count overflow and
;    underflow.
;
;****************************************************************************
*/

#include "SwchFltr.h"


//***************************************************************************
//Main() - Main Routine
//***************************************************************************
void main(void)
{
	Init();
	while(1)
	{
		if(T0IF)
		{
			T0IF = 0;	// reset flag
			TestSwitch();
		}
	}
	
}

//***************************************************************************
//Init - Initialization Routine
//***************************************************************************
void Init(void)
{
	/* Comment out if using simulator, ICD2, or ICE2000
	#asm   
		call 0x3FF	//Load Factory Calibration Value Into OSCCAL
		bsf _STATUS,5  //BANK1
		movwf _OSCCAL
	#endasm
	*/

	ANSEL = 0b00000000;	// configure A/D inputs as digital I/O
	TRISIO = D0_1Tris;		// GPIO 3,4 outputs, GPIO 0,1,2,5,6,7 inputs
	OPTION = 0b11010001;	// Timer0 internal clock, 1:4 prescale
	GPIO = D0On;			// initial state is switch open and D0 on
	CMCON = 0b00000000;	// configure comparator inputs as digital I/O
}

//***************************************************************************
//Functions
//***************************************************************************

//***************************************************************************
//TestSwitch - Test switch state and take action when filter count saturates
//***************************************************************************
void TestSwitch(void)
{
	static unsigned char FilterCount=0.;
	
	if(BUTTON)
	{
		// switch is open
		if(FilterCount > MinCount)
		{
			// drive LED0 when FilterCount saturates at MinCount
			if(--FilterCount<=MinCount)
			{
				GPIO = D0On;
			}
		}
	}
	else
	{
		// switch is closed
		if(FilterCount<MaxCount)
		{
			// drive LED1 when FilterCount saturates at MaxCount
			if(++FilterCount>=MaxCount)
			{
				GPIO = D1On;
			}
		}
	}
}
